@@ -1,5 +1,5 @@
 #!/bin/sh
-V="5.1.1"
+V="5.3"
 prefix=/usr
 infodir=${prefix}/share/info
 docdir=${prefix}/share/doc
